// Login.swift

import Foundation
import ArgumentParser
import Get

extension Seanut {
    struct LoginCommand: AsyncParsableCommand {
        static var configuration = CommandConfiguration(
          commandName: "login",
          abstract: "Logs in as specified user to specified jellyfin server. caches access token for later invocations"
        )

        @OptionGroup var options: Seanut.CommonArguments

        @Option(name: .shortAndLong, help: "username for the jellyfin server")
        var username: String
        
        @Option(name: .shortAndLong, help: "password for the jellyfin server")
        var password: String?

        mutating func run() async {
            Seanut.maybeSetLogger(options)

            let seanutCacheFolder = "~/.seanut/".expandingTildeInPath
            
            if !FileManager.default.fileExists(atPath: seanutCacheFolder) {
                do {
                    try FileManager.default.createDirectory(
                      at: URL(fileURLWithPath: seanutCacheFolder),
                      withIntermediateDirectories: false
                    )
                } catch {
                    fatalError("could not create seanut token cache folder. quitting...")
                }
            }

            let client = APIClient(baseURL: options.domain.toURL()!)
            
            await Seanut.getAccessToken(
              client: client,
              username: username,
              password: password
            )
        }
    }
}
