// Search.swift

import Foundation
import ArgumentParser
import Get

extension Seanut {
    struct SearchCommand: AsyncParsableCommand {
        static var configuration = CommandConfiguration(
          commandName: "search",
          abstract: "Searches for <media-name>"
        )

        @OptionGroup var options: Seanut.CommonArguments
        
        @Argument(help: "media query")
        var query: String

        static let columnWidth = 40
        
        mutating func run() async {
            Seanut.maybeSetLogger(options)
            let config = Seanut.generateJellyfinConfiguration(
              url: options.domain.toURL()!,
              token: Seanut.retrieveAccessToken(for: options.domain.toURL()!)
            )
            
            let client = APIClient(baseURL: options.domain.toURL()!)
            let searchRequest: Request<SearchResult> = Seanut.jellyfinRequest(
              result: SearchResult(), 
              config: config, 
              path: "/Items", 
              method: .get, 
              query: [
                ("recursive", "true"),
                ("fields", "Path,ChildCount"),
                ("searchTerm", query),
                ("includeItemTypes", "MusicAlbum,MusicArtist,Movie,Book,Playlist,Series,Audio")
              ]
            )

            let response = try? await client.send(searchRequest).value
            
            if let items = response?.items {
                print("Found \(items.count) results:")
                let header = "ID".padding(toLength: SearchCommand.columnWidth, withPad: " ", startingAt: 0) +
                  "Type".padding(toLength: 15, withPad: " ", startingAt: 0) +
                  "Name".padding(toLength: SearchCommand.columnWidth, withPad: " ", startingAt: 0)
                print(header)
                
                for i in items {
                    let item = i.id!.padding(toLength: SearchCommand.columnWidth, withPad: " ", startingAt: 0) +
                      i.type!.padding(toLength: 15, withPad: " ", startingAt: 0) +
                      i.name!.padding(toLength: SearchCommand.columnWidth, withPad: " ", startingAt: 0)
                    print(item)
                }
            } else {
                print("Found no results. Please try your query again...")
            }
        }
    }
}
